<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>浏览器之外，生活亦精彩！</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>遵循协议：%1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 是自由软件。其开发也同样要耗用宝贵时间的。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>恭迎您慷慨&lt;a href=&apos;%1&apos;&gt;捐赠&lt;/a&gt;，支持我们继续开发 %2 。</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>使用 %2 将 %1 翻译为您的母语</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>由 %1 强力驱动</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>开源软件</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>图标设计：%1。</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>本软件遵循&lt;a href=&apos;%1&apos;&gt;GNU通用公共许可证&lt;/a&gt;予以发布。</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>输入您的许可协议详情</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>邮件(&amp;E)：</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>激活码(C)：</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>请购买 %1 授权</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>完整版本允许你不被中断观看视频</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>通过购买完整版本，您也将支持我在创建 %1 时的辛苦工作。</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>使用 Demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>输入许可</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>购买许可</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>由 %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>你有 %n 个新视频</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>所有视频</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>未观看视频</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>姓名</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>最后更新</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>最后添加</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>最后观看</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>最多观看</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>排序</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>将所有标记为已观看</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>显示更新</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>你没有任何订阅，使用星形符号订阅频道</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>所有视频</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>未观看视频</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>标记为已观看</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>取消订阅</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>当前没有订阅更新</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>刚刚</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n 小时前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n 天前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n 月前</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 人次观看</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n 周前</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>%n 年前</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>字节</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>千字节</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>兆字节</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>字节/秒</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>千字节/秒</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>兆字节/秒</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>剩余 %4 %5 </translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 已下载(%2)</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>下载完成</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n 个下载</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>更改存储位置……</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>选择下载存储位置</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>下载存储位置已修改。</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>当前下载仍然保持前一个存储位置。</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>当前下载存储位置：%1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>下载情况</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>可执行文件已经被篡改，或许是病毒感染了</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 将不会被执行，请尝试重装。</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>重新安装</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>当前轨道后停止播放</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>下一轨道</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>上一轨道</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>增加音量</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>减小音量</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>向前搜索</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>向后搜索</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>按关键词查找视频和频道</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>按分类查找视频</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>订阅</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>频道订阅</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>请您尽情享受吧！</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>窗口(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>最小化(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>停止回放并返回搜索视图</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>上一首(&amp;R)</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>饭回到上一首音轨</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>跳过(&amp;k)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>跳至下一视频</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>播放(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>恢复播放</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>全屏播放</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>紧凑模式(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>隐藏播放列表和工具栏</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>打开 YouTube 页面(&amp;Y)</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>打开YouTube视频页面并暂停回放</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>复制 YouTube 链接(&amp;L)</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>复制当前视频的YouTube链接到剪贴板中</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>复制视频流 URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>复制当前视频流的URL到剪贴板中</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>查找视频部分(&amp;P)</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>以正确的顺序查找其他视频部分</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>从播放列表中移除选定的视频</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>上移(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>在播放列表中向上移动选定的视频</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>下移(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>在播放列表中向下移动选定的视频</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>清除最近的搜索(&amp;C)</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>清除搜索历史。注意：清除的历史不可恢复。</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>再见</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>网站(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1在网站上</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>捐助(&amp;D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>请您支持 %1 的继续开发</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>关于 %1 的信息</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>手动开始播放(&amp;M)</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>手动开始播放视频</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>下载(&amp;D)</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>显示视频下载详情</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>下载(&amp;D)</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>下载当前视频</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>截屏 (&amp;s)</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>订阅频道(&amp;S)</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>使用 %1 分享当前视频</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>电子邮件(&amp;E)</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>电子邮件</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>窗口置顶(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>该视频后停止播放(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>报告问题&amp;R…</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>精确搜索(&amp;R)...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>更多...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>相关视频(&amp;R)</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>查看与当前视频相关的视频</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>在浏览器中打开(&amp;B)</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>受限模式</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>隐藏可能含有不恰当内容的视频</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>切换菜单栏（&amp;M）</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>菜单</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>喜欢 %1? 为其评分！</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>购买 %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>应用程序(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>播放(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>播放列表(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>视频(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>分享(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>按住 %1 提高音量，%2 降低音量</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>选择您的内容位置</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>正在打开 %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>当前还有尚未完成的下载。您确定要退出 %1 吗？</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>如果您现在关闭 %1 ，那么本下载将被取消。</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>关闭并取消下载</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>等待下载完成</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>错误：%1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>暂停(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>暂停回放</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>加载中...（&amp;L）</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>离开全屏模式(&amp;F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>剩余时间：%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>已设为静音</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>静音已解除</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>最大视频定义设置为%1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>您的隐私已受保护</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>下载完成</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>按住 ALT 键以访问菜单栏</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>您现在可以把YouTube的链接粘贴到其他应用了</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>您现在可以把视频流的链接粘贴到其他应用了</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>此链接仅能保持短时间的有效性。</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>正在下载 %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>之</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>部分</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>集</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>由 %1 发送</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>取消订阅 %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>订阅 %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>切换到 %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>从 %1 退订</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>订阅 %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation>回退 %1 秒</translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation>快进 %1 秒</translation>
    </message>
    <message>
        <source>channel</source>
        <translation>频道</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>发现新版本的 %1 ！</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 已经可用。您现拥有 %3。</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>您想现在下载吗？</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>跳过此版本</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>稍后提醒我</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>安装更新</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>选择一个视频</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 之 %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>准备中</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>已失败</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>已停止</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>停止下载</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>显示到 %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>打开上层目录</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>重新下载</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>再多显示 %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>没有视频</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>没有更多视频</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>排序</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>相关性</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>查看计数</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>评分</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>任何时候</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 天</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 天</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>持续时长</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>短</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中等</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>长</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>少于 4 分钟</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4 到 20 分钟之间</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>长于 20 分钟</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>今年</translation>
    </message>
    <message>
        <source>HD</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>HDR</source>
        <translation>HDR</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>欢迎使用&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;！</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>开始观看视频。</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>关键字</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>输入</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>最近关键字词</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>最近频道</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>获取完整版</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation>想要远程控制 %1？试试 %2！</translation>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation>我一直在尽力改进 %1。请支持这个作品！</translation>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation>更新已准备好，退出并安装更新</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>后退(_B)</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>前进（&amp;F）</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>前进至 %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>返回到 %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>二次检索</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>您的意思是：%1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>更改存储位置……</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>截图已保存到 %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>截图位置已改变。</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>最流行</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation>趋势</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>News</source>
        <translation>新闻</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>电影</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>游戏</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>正在下载更新...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>正在下载 %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation>查检更新</translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation>版本 %1 可用</translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation>下载版本 %1...</translation>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation>重启开始更新</translation>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation>版本 %1 下载失败</translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation>查检更新</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>下载更新</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>正在下载更新...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation>重试下载更新</translation>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation>已是最新版本</translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>版本 %1 可用</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation>更新下载，准备更新</translation>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>无法获得视频流。可能原因：%1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>阿尔及利亚</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>阿根廷</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>澳大利亚</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>比利时</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>巴西</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>加拿大</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>智利</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>哥伦比亚</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>捷克共和国</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>埃及</translation>
    </message>
    <message>
        <source>France</source>
        <translation>法国</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>德国</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>加纳</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>希腊</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>香港</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>匈牙利</translation>
    </message>
    <message>
        <source>India</source>
        <translation>印度</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>印度尼西亚</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>爱尔兰</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>以色列</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>意大利</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>日本</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>约旦</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>肯尼亚</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>马来西亚</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>墨西哥</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>摩洛哥</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>荷兰</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>新西兰</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>尼日利亚</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>秘鲁</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>菲律宾</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>波兰</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>俄罗斯</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>沙特阿拉伯</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>新加坡</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>南非</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>韩国</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>西班牙</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>瑞士</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>台湾</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>突尼斯</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>土耳其</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>乌干达</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>阿联酋</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>英国</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>也门</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>全球</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>无法获得视频流。可能原因：%1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation>当前没有更新可用</translation>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation>已是最新版本</translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation>已下载 %1 %2...</translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>发现新版本的 %1 ！</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 已经可用。您现拥有 %3。</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>您想现在下载吗？</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>稍后提醒我</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>下载更新</translation>
    </message>
</context>
</TS>